/*
 * libfeedback
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __SVI_IDS_H__
#define __SVI_IDS_H__

typedef enum svi_type_t {
	SVI_TYPE_NONE,
	SVI_TYPE_SND,
	SVI_TYPE_VIB,
	SVI_TYPE_END
} svi_type;

typedef enum sound_type_t {
	SVI_SND_NONE = -1,

	/* TOUCH : SCREEN TOUCH : TAP(TOUCH & RELEASE) : GENERAL */
	SVI_SND_TOUCH_TOUCH1 = 0,
	SVI_SND_TOUCH_TOUCH2,
	SVI_SND_TOUCH_TOUCH3,
	/* TOUCH : SCREEN TOUCH : TAP(TOUCH & RELEASE) : TEXT_NUMERIC_INPUT */
	SVI_SND_TOUCH_SIP,
	SVI_SND_TOUCH_SIP_BACKSPACE,
	/* TOUCH : SCREEN TOUCH : TAP(TOUCH & RELEASE) : DAILER */
	SVI_SND_TOUCH_KEY00,
	SVI_SND_TOUCH_KEY01,
	SVI_SND_TOUCH_KEY02,
	SVI_SND_TOUCH_KEY03,
	SVI_SND_TOUCH_KEY04,
	SVI_SND_TOUCH_KEY05,
	SVI_SND_TOUCH_KEY06,
	SVI_SND_TOUCH_KEY07,
	SVI_SND_TOUCH_KEY08,
	SVI_SND_TOUCH_KEY09,
	SVI_SND_TOUCH_KEY_STAR,
	SVI_SND_TOUCH_KEY_SHARP,
	/* TOUCH : H/W OR SOFT TOUCH : HOLD(TAP & HOLD) */
	SVI_SND_TOUCH_HOLD,
	/* TOUCH : H/W OR SOFT TOUCH : MULTI TAP */
	SVI_SND_TOUCH_MULTI_TAP,
	/* TOUCH : H/W OR SOFT TOUCH : TAP */
	SVI_SND_TOUCH_HW_TAP,
	/* TOUCH : H/W OR SOFT TOUCH : TAP & HOLD */
	SVI_SND_TOUCH_HW_HOLD,

	/* OPERATION : POWER ON/OFF */
	SVI_SND_OPERATION_POWERON,
	SVI_SND_OPERATION_POWEROFF,
	/* OPERATION : CHARGECONN */
	SVI_SND_OPERATION_CHARGERCONN,
	/* OPERATION : FULLCHAREGED */
	SVI_SND_OPERATION_FULLCHARGED,
	/* OPERATION : LOW BATTERY */
	SVI_SND_OPERATION_LOWBATT,
	/* OPERATION : LOCK/UNLOCK */
	SVI_SND_OPERATION_LOCK,
	SVI_SND_OPERATION_UNLOCK,
	/* OPERATION : CALL CONNECT/ DISCONNECT */
	SVI_SND_OPERATION_CALLCONN,
	SVI_SND_OPERATION_CALLDISCONN,
	/* OPERATION : MINUTE MINDER */
	SVI_SND_OPERATION_MINUTE_MINDER,
	/* OPERATION : VIBRATION */
	SVI_SND_OPERATION_VIBRATION,
	/* OPERATION : BALLOON MESSAGE SEND/RECV */
	SVI_SND_OPERATION_NEWCHAT,
	SVI_SND_OPERATION_SENTCHAT,
	/* OPERATION : ON/OFF SLIDER */
	SVI_SND_OPERATION_ONOFFSLIDER,
	/* OPERATION : CAMERA SHUTTER / SCREEN CAPTURE */
	SVI_SND_OPERATION_SCRCAPTURE,
	/* OPERATION : LIST RE-ORDER */
	SVI_SND_OPERATION_LIST_REORDER,
	/* OPERATION : LIST SLIDER */
	SVI_SND_OPERATION_SLIDER_SWEEP,
	SVI_SND_ENUM_END
} sound_type;

typedef enum vibration_type_t {
	SVI_VIB_NONE = -1,

	/* TOUCH : SCREEN TOUCH : TAP(TOUCH & RELEASE) : GENERAL */
	SVI_VIB_TOUCH_TOUCH = 0,
	/* TOUCH : SCREEN TOUCH : TAP(TOUCH & RELEASE) : TEXT_NUMERIC_INPUT */
	SVI_VIB_TOUCH_SIP,
	SVI_VIB_TOUCH_SIP_BACKSPACE,
	/* TOUCH : SCREEN TOUCH : TAP(TOUCH & RELEASE) : DAILER */
	SVI_VIB_TOUCH_KEY00,
	SVI_VIB_TOUCH_KEY01,
	SVI_VIB_TOUCH_KEY02,
	SVI_VIB_TOUCH_KEY03,
	SVI_VIB_TOUCH_KEY04,
	SVI_VIB_TOUCH_KEY05,
	SVI_VIB_TOUCH_KEY06,
	SVI_VIB_TOUCH_KEY07,
	SVI_VIB_TOUCH_KEY08,
	SVI_VIB_TOUCH_KEY09,
	SVI_VIB_TOUCH_KEY_STAR,
	SVI_VIB_TOUCH_KEY_SHARP,
	/* TOUCH : H/W OR SOFT TOUCH : HOLD(TAP & HOLD) */
	SVI_VIB_TOUCH_HOLD,
	/* TOUCH : H/W OR SOFT TOUCH : MULTI TAP */
	SVI_VIB_TOUCH_MULTI_TAP,
	/* TOUCH : H/W OR SOFT TOUCH : TAP */
	SVI_VIB_TOUCH_HW_TAP,
	/* TOUCH : H/W OR SOFT TOUCH : TAP & HOLD */
	SVI_VIB_TOUCH_HW_HOLD,

	/* NOTIFICATION : INCOMING : CALL */
	SVI_VIB_NOTIFICATION_INCOMING_CALL01,
	SVI_VIB_NOTIFICATION_INCOMING_CALL02,
	SVI_VIB_NOTIFICATION_INCOMING_CALL03,
	SVI_VIB_NOTIFICATION_INCOMING_CALL04,
	SVI_VIB_NOTIFICATION_INCOMING_CALL05,
	SVI_VIB_NOTIFICATION_INCOMING_CALL06,
	/* NOTIFICATION : INCOMING : MESSAGE */
	SVI_VIB_NOTIFICATION_MESSAGE,
	/* NOTIFICATION : INCOMING : EMAIL */
	SVI_VIB_NOTIFICATION_EMAIL,
	/* NOTIFICATION : ALARM : WAKEUP */
	SVI_VIB_NOTIFICATION_WAKEUP,
	/* NOTIFICATION : ALARM : SCHEDULE */
	SVI_VIB_NOTIFICATION_SCHEDULE,
	/* NOTIFICATION : ALARM : TIMER */
	SVI_VIB_NOTIFICATION_TIMER,
	/* NOTIFICATION : GENERAL(TICKER/IM/SMS ETC) */
	SVI_VIB_NOTIFICATION_GENERAL,

	/* OPERATION : POWER ON/OFF */
	SVI_VIB_OPERATION_POWER_ON,
	SVI_VIB_OPERATION_POWER_OFF,
	/* OPERATION : CHARGECONN */
	SVI_VIB_OPERATION_CHARGERCONN,
	/* OPERATION : FULLCHAREGED */
	SVI_VIB_OPERATION_FULLCHARGED,
	/* OPERATION : LOW BATTERY */
	SVI_VIB_OPERATION_LOWBATT,
	/* OPERATION : LOCK/UNLOCK */
	SVI_VIB_OPERATION_LOCK,
	SVI_VIB_OPERATION_UNLOCK,
	/* OPERATION : CALL CONNECT/ DISCONNECT */
	SVI_VIB_OPERATION_CALLCONNECT,
	SVI_VIB_OPERATION_DISCALLCONNECT,
	/* OPERATION : MINUTE MINDER */
	SVI_VIB_OPERATION_MINUTEMINDER,
	/* OPERATION : VIBRATION */
	SVI_VIB_OPERATION_VIBRATION,
	/* OPERATION : BALLOON MESSAGE SEND/RECV */
	SVI_VIB_OPERATION_NEWCHAT,
	SVI_VIB_OPERATION_SENDCHAT,
	/* OPERATION : ON/OFF SLIDER */
	SVI_VIB_OPERATION_ONOFFSLIDER,
	/* OPERATION : CAMERA SHUTTER / SCREEN CAPTURE */
	SVI_VIB_OPERATION_SHUTTER,
	/* OPERATION : LIST RE-ORDER */
	SVI_VIB_OPERATION_LIST_REORDER,
	/* OPERATION : LIST SLIDER */
	SVI_VIB_OPERATION_SLIDER_SWEEP,

	SVI_VIB_ENUM_END

} vibration_type;

#endif //__SVI_IDS_H__
